Documentation
¶
Index ¶
Constants ¶
const ( ErrBadEntry = err.Const("bad plugin entry point") ErrNoSymbol = err.Const("no symbol found") )
const ErrRebuild = err.Const("plugin may need to be rebuilt")
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Constructor ¶
type Constructor string
Constructor is a supported constructor type. Callers should pass in one of the Constructor constants, so we know which constructor to look up in the plugin files.
const ( Actions Constructor = "Actions" UIs Constructor = "UIs" )
type LazyConfig ¶
type LazyConfig struct {
// contains filtered or unexported fields
}
func (*LazyConfig) UnmarshalConfig ¶
func (l *LazyConfig) UnmarshalConfig(ctx context.Context, decode func(any) error)
Click to show internal directories.
Click to hide internal directories.